#ifndef TCLMIDI_H
#define TCLMIDI_H

#include "TclmIntp.h"

extern int Tclm_Init(Tcl_Interp *interp);
extern int Tclm_PlayInit(Tcl_Interp *interp, TclmInterp *tclm_interp);
extern int Tcl_GetLong(Tcl_Interp *interp, const char *string, long *longPtr);
extern int Tclm_ParseDataByte(Tcl_Interp *interp, const char *str,
    unsigned char *val);
extern void Tclm_PrintData(ostream &buf, const unsigned char *data,
    long length);
#endif
